"""LMU provides a package for deep learning with Legendre Memory Units."""

from .layers import (
    LMUCell,
    LMUFFT,
    LMU,
)

from .version import version as __version__

__copyright__ = "2019-2020, Applied Brain Research"
__license__ = "Free for non-commercial use; see LICENSE.rst"
